@@ -34,63 +34,77 @@ def login(
 
 
 def get_catalog_options(
+        max_concurrent: int = 3,
         request_delay: float | int = 1,
-        async_limit: int = 3,
         progress: bool = True,
     ) -> dict:
     return dict(
-        PaginateAll = dict(delay=request_delay, limit=async_limit),
-        RequestEachPages = dict(delay=request_delay, limit=async_limit, tqdm_options=dict(disable=(not progress))))
+        PaginateAll = dict(max_concurrent=max_concurrent, request_delay=request_delay, tqdm_options=dict(disable=(not progress))),
+        RequestEachPages = dict(max_concurrent=max_concurrent, request_delay=request_delay, tqdm_options=dict(disable=(not progress))),
+    )
 
 
 def get_sales_options(
+        max_concurrent: int = 3,
         request_delay: float | int = 1,
-        async_limit: int = 3,
         progress: bool = True,
     ) -> dict:
-    return dict(RequestEach = dict(delay=request_delay, limit=async_limit, tqdm_options=dict(disable=(not progress))))
+    return dict(
+        RequestEach = dict(request_delay=request_delay, max_concurrent=max_concurrent, tqdm_options=dict(disable=(not progress))),
+    )
 
 
 def brand_catalog(
         cookies: str,
         brand_ids: str | Iterable[str],
-        sort_type: Literal["popular","recent","price"] = "poular",
+        sort_type: Literal["popular","recent","price"] = "recent",
         is_brand_catalog: bool | None = None,
         page: int | list[int] | None = 0,
         page_size: int = 100,
         connection: DuckDBConnection | None = None,
+        tables: dict | None = None,
         how: Literal["sync","async","async_loop"] = "sync",
+        max_concurrent: int = 3,
         request_delay: float | int = 1,
-        async_limit: int = 3,
         progress: bool = True,
         return_type: Literal["csv","json","parquet","raw","none"] = "json",
         extract_options: dict = dict(),
         transform_options: dict = dict(),
     ) -> JsonObject:
     """`tables = {'default': 'data'}`"""
-    from linkmerce.core.smartstore.brand.catalog.extract import BrandCatalog
+    # from linkmerce.core.smartstore.brand.catalog.extract import BrandCatalog
     # from linkmerce.core.smartstore.brand.catalog.transform import BrandCatalog
-    components = (get_module(".catalog"), "BrandCatalog", "BrandCatalog")
-    args = (brand_ids, sort_type, is_brand_catalog, page, page_size)
-    extract_options = update_options(extract_options,
-        headers = dict(cookies=cookies),
-        options = get_catalog_options(request_delay, async_limit, progress))
-    options = dict(extract_options=extract_options, transform_options=transform_options)
-    return run_with_duckdb(*components, connection, how, return_type, args, **options)
+    return run_with_duckdb(
+        module = get_module(".catalog"),
+        extractor = "BrandCatalog",
+        transformer = "BrandCatalog",
+        connection = connection,
+        tables = tables,
+        how = how,
+        return_type = return_type,
+        args = (brand_ids, sort_type, is_brand_catalog, page, page_size),
+        extract_options = update_options(
+            extract_options,
+            headers = dict(cookies=cookies),
+            options = get_catalog_options(max_concurrent, request_delay, progress),
+        ),
+        transform_options = transform_options,
+    )
 
 
 def brand_product(
         cookies: str,
         brand_ids: str | Iterable[str],
         mall_seq: int | str | Iterable[int | str] | None = None,
-        sort_type: Literal["popular","recent","price"] = "poular",
+        sort_type: Literal["popular","recent","price"] = "recent",
         is_brand_catalog: bool | None = None,
         page: int | list[int] | None = 0,
         page_size: int = 100,
         connection: DuckDBConnection | None = None,
+        tables: dict | None = None,
         how: Literal["sync","async","async_loop"] = "sync",
+        max_concurrent: int = 3,
         request_delay: float | int = 1,
-        async_limit: int = 3,
         progress: bool = True,
         return_type: Literal["csv","json","parquet","raw","none"] = "json",
         extract_options: dict = dict(),
@@ -99,13 +113,22 @@ def brand_product(
     """`tables = {'default': 'data'}`"""
     # from linkmerce.core.smartstore.brand.catalog.extract import BrandProduct
     # from linkmerce.core.smartstore.brand.catalog.transform import BrandProduct
-    components = (get_module(".catalog"), "BrandProduct", "BrandProduct")
-    args = (brand_ids, mall_seq, sort_type, is_brand_catalog, page, page_size)
-    extract_options = update_options(extract_options,
-        headers = dict(cookies=cookies),
-        options = get_catalog_options(request_delay, async_limit, progress))
-    options = dict(extract_options=extract_options, transform_options=transform_options)
-    return run_with_duckdb(*components, connection, how, return_type, args, **options)
+    return run_with_duckdb(
+        module = get_module(".catalog"),
+        extractor = "BrandProduct",
+        transformer = "BrandProduct",
+        connection = connection,
+        tables = tables,
+        how = how,
+        return_type = return_type,
+        args = (brand_ids, mall_seq, sort_type, is_brand_catalog, page, page_size),
+        extract_options = update_options(
+            extract_options,
+            headers = dict(cookies=cookies),
+            options = get_catalog_options(max_concurrent, request_delay, progress),
+        ),
+        transform_options = transform_options,
+    )
 
 
 def brand_price(
@@ -117,9 +140,10 @@ def brand_price(
         page: int | list[int] | None = 0,
         page_size: int = 100,
         connection: DuckDBConnection | None = None,
+        tables: dict | None = None,
         how: Literal["sync","async","async_loop"] = "sync",
+        max_concurrent: int = 3,
         request_delay: float | int = 1,
-        async_limit: int = 3,
         progress: bool = True,
         return_type: Literal["csv","json","parquet","raw","none"] = "json",
         extract_options: dict = dict(),
@@ -128,13 +152,22 @@ def brand_price(
     """`tables = {'price': 'naver_brand_price', 'product': 'naver_brand_product'}`"""
     # from linkmerce.core.smartstore.brand.catalog.extract import BrandPrice
     # from linkmerce.core.smartstore.brand.catalog.transform import BrandPrice
-    components = (get_module(".catalog"), "BrandPrice", "BrandPrice")
-    args = (brand_ids, mall_seq, sort_type, is_brand_catalog, page, page_size)
-    extract_options = update_options(extract_options,
-        headers = dict(cookies=cookies),
-        options = get_catalog_options(request_delay, async_limit, progress))
-    options = dict(extract_options=extract_options, transform_options=transform_options)
-    return run_with_duckdb(*components, connection, how, return_type, args, **options)
+    return run_with_duckdb(
+        module = get_module(".catalog"),
+        extractor = "BrandPrice",
+        transformer = "BrandPrice",
+        connection = connection,
+        tables = tables,
+        how = how,
+        return_type = return_type,
+        args = (brand_ids, mall_seq, sort_type, is_brand_catalog, page, page_size),
+        extract_options = update_options(
+            extract_options,
+            headers = dict(cookies=cookies),
+            options = get_catalog_options(max_concurrent, request_delay, progress),
+        ),
+        transform_options = transform_options,
+    )
 
 
 def product_catalog(
@@ -146,9 +179,10 @@ def product_catalog(
         page: int | list[int] | None = 0,
         page_size: int = 100,
         connection: DuckDBConnection | None = None,
+        tables: dict | None = None,
         how: Literal["sync","async","async_loop"] = "sync",
+        max_concurrent: int = 3,
         request_delay: float | int = 1,
-        async_limit: int = 3,
         progress: bool = True,
         return_type: Literal["csv","json","parquet","raw","none"] = "json",
         extract_options: dict = dict(),
@@ -157,13 +191,22 @@ def product_catalog(
     """`tables = {'default': 'data'}`"""
     # from linkmerce.core.smartstore.brand.catalog.extract import ProductCatalog
     # from linkmerce.core.smartstore.brand.catalog.transform import ProductCatalog
-    components = (get_module(".catalog"), "ProductCatalog", "ProductCatalog")
-    args = (brand_ids, mall_seq, sort_type, is_brand_catalog, page, page_size)
-    extract_options = update_options(extract_options,
-        headers = dict(cookies=cookies),
-        options = get_catalog_options(request_delay, async_limit, progress))
-    options = dict(extract_options=extract_options, transform_options=transform_options)
-    return run_with_duckdb(*components, connection, how, return_type, args, **options)
+    return run_with_duckdb(
+        module = get_module(".catalog"),
+        extractor = "ProductCatalog",
+        transformer = "ProductCatalog",
+        connection = connection,
+        tables = tables,
+        how = how,
+        return_type = return_type,
+        args = (brand_ids, mall_seq, sort_type, is_brand_catalog, page, page_size),
+        extract_options = update_options(
+            extract_options,
+            headers = dict(cookies=cookies),
+            options = get_catalog_options(max_concurrent, request_delay, progress),
+        ),
+        transform_options = transform_options,
+    )
 
 
 def store_sales(
@@ -175,9 +218,10 @@ def store_sales(
         page: int | Iterable[int] = 1,
         page_size: int = 1000,
         connection: DuckDBConnection | None = None,
+        tables: dict | None = None,
         how: Literal["sync","async","async_loop"] = "sync",
+        max_concurrent: int = 3,
         request_delay: float | int = 1,
-        async_limit: int = 3,
         progress: bool = True,
         return_type: Literal["csv","json","parquet","raw","none"] = "json",
         extract_options: dict = dict(),
@@ -186,13 +230,22 @@ def store_sales(
     """`tables = {'default': 'data'}`"""
     # from linkmerce.core.smartstore.brand.sales.extract import StoreSales
     # from linkmerce.core.smartstore.brand.sales.transform import StoreSales
-    components = (get_module(".sales"), "StoreSales", "StoreSales")
-    args = (mall_seq, start_date, end_date, date_type, page, page_size)
-    extract_options = update_options(extract_options,
-        headers = dict(cookies=cookies),
-        options = get_sales_options(request_delay, async_limit, progress))
-    options = dict(extract_options=extract_options, transform_options=transform_options)
-    return run_with_duckdb(*components, connection, how, return_type, args, **options)
+    return run_with_duckdb(
+        module = get_module(".sales"),
+        extractor = "StoreSales",
+        transformer = "StoreSales",
+        connection = connection,
+        tables = tables,
+        how = how,
+        return_type = return_type,
+        args = (mall_seq, start_date, end_date, date_type, page, page_size),
+        extract_options = update_options(
+            extract_options,
+            headers = dict(cookies=cookies),
+            options = get_sales_options(max_concurrent, request_delay, progress),
+        ),
+        transform_options = transform_options,
+    )
 
 
 def category_sales(
@@ -204,9 +257,10 @@ def category_sales(
         page: int | Iterable[int] = 1,
         page_size: int = 1000,
         connection: DuckDBConnection | None = None,
+        tables: dict | None = None,
         how: Literal["sync","async","async_loop"] = "sync",
+        max_concurrent: int = 3,
         request_delay: float | int = 1,
-        async_limit: int = 3,
         progress: bool = True,
         return_type: Literal["csv","json","parquet","raw","none"] = "json",
         extract_options: dict = dict(),
@@ -215,13 +269,22 @@ def category_sales(
     """`tables = {'default': 'data'}`"""
     # from linkmerce.core.smartstore.brand.sales.extract import CategorySales
     # from linkmerce.core.smartstore.brand.sales.transform import CategorySales
-    components = (get_module(".sales"), "CategorySales", "CategorySales")
-    args = (mall_seq, start_date, end_date, date_type, page, page_size)
-    extract_options = update_options(extract_options,
-        headers = dict(cookies=cookies),
-        options = get_sales_options(request_delay, async_limit, progress))
-    options = dict(extract_options=extract_options, transform_options=transform_options)
-    return run_with_duckdb(*components, connection, how, return_type, args, **options)
+    return run_with_duckdb(
+        module = get_module(".sales"),
+        extractor = "CategorySales",
+        transformer = "CategorySales",
+        connection = connection,
+        tables = tables,
+        how = how,
+        return_type = return_type,
+        args = (mall_seq, start_date, end_date, date_type, page, page_size),
+        extract_options = update_options(
+            extract_options,
+            headers = dict(cookies=cookies),
+            options = get_sales_options(max_concurrent, request_delay, progress),
+        ),
+        transform_options = transform_options,
+    )
 
 
 def product_sales(
@@ -233,9 +296,10 @@ def product_sales(
         page: int | Iterable[int] = 1,
         page_size: int = 1000,
         connection: DuckDBConnection | None = None,
+        tables: dict | None = None,
         how: Literal["sync","async","async_loop"] = "sync",
+        max_concurrent: int = 3,
         request_delay: float | int = 1,
-        async_limit: int = 3,
         progress: bool = True,
         return_type: Literal["csv","json","parquet","raw","none"] = "json",
         extract_options: dict = dict(),
@@ -244,13 +308,22 @@ def product_sales(
     """`tables = {'default': 'data'}`"""
     # from linkmerce.core.smartstore.brand.sales.extract import ProductSales
     # from linkmerce.core.smartstore.brand.sales.transform import ProductSales
-    components = (get_module(".sales"), "ProductSales", "ProductSales")
-    args = (mall_seq, start_date, end_date, date_type, page, page_size)
-    extract_options = update_options(extract_options,
-        headers = dict(cookies=cookies),
-        options = get_sales_options(request_delay, async_limit, progress))
-    options = dict(extract_options=extract_options, transform_options=transform_options)
-    return run_with_duckdb(*components, connection, how, return_type, args, **options)
+    return run_with_duckdb(
+        module = get_module(".sales"),
+        extractor = "ProductSales",
+        transformer = "ProductSales",
+        connection = connection,
+        tables = tables,
+        how = how,
+        return_type = return_type,
+        args = (mall_seq, start_date, end_date, date_type, page, page_size),
+        extract_options = update_options(
+            extract_options,
+            headers = dict(cookies=cookies),
+            options = get_sales_options(max_concurrent, request_delay, progress),
+        ),
+        transform_options = transform_options,
+    )
 
 
 def aggregated_sales(
@@ -262,9 +335,10 @@ def aggregated_sales(
         page: int | Iterable[int] = 1,
         page_size: int = 1000,
         connection: DuckDBConnection | None = None,
+        tables: dict | None = None,
         how: Literal["sync","async","async_loop"] = "sync",
+        max_concurrent: int = 3,
         request_delay: float | int = 1,
-        async_limit: int = 3,
         progress: bool = True,
         return_type: Literal["csv","json","parquet","raw","none"] = "json",
         extract_options: dict = dict(),
@@ -273,10 +347,19 @@ def aggregated_sales(
     """`tables = {'sales': 'naver_brand_sales', 'product': 'naver_brand_product'}`"""
     # from linkmerce.core.smartstore.brand.sales.extract import AggregatedSales
     # from linkmerce.core.smartstore.brand.sales.transform import AggregatedSales
-    components = (get_module(".sales"), "AggregatedSales", "AggregatedSales")
-    args = (mall_seq, start_date, end_date, date_type, page, page_size)
-    extract_options = update_options(extract_options,
-        headers = dict(cookies=cookies),
-        options = get_sales_options(request_delay, async_limit, progress))
-    options = dict(extract_options=extract_options, transform_options=transform_options)
-    return run_with_duckdb(*components, connection, how, return_type, args, **options)
+    return run_with_duckdb(
+        module = get_module(".sales"),
+        extractor = "AggregatedSales",
+        transformer = "AggregatedSales",
+        connection = connection,
+        tables = tables,
+        how = how,
+        return_type = return_type,
+        args = (mall_seq, start_date, end_date, date_type, page, page_size),
+        extract_options = update_options(
+            extract_options,
+            headers = dict(cookies=cookies),
+            options = get_sales_options(max_concurrent, request_delay, progress),
+        ),
+        transform_options = transform_options,
+    )
