@@ -15,8 +15,9 @@ class ExposureDiagnosis(SearchAdManager):
     @property
     def default_options(self) -> dict:
         return dict(
-            RequestLoop = dict(count=5, raise_errors=RuntimeError, ignored_errors=Exception),
-            RequestEachLoop = dict(delay=1.01))
+            RequestLoop = dict(max_retries=5, raise_errors=RuntimeError, ignored_errors=Exception),
+            RequestEachLoop = dict(request_delay=1.01),
+        )
 
     @SearchAdManager.with_session
     @SearchAdManager.with_token
