@@ -86,7 +86,7 @@ class BigQueryClient(Connection):
         except:
             pass
 
-    def retry_on_concurrent_update(max_retries: int = 5, delay: float | int = 1):
+    def retry_on_concurrent_update(max_retries: int = 5, delay: float | int = 1, random_delay: tuple[float,float] | None = None):
         # BadRequest: 400 POST https://bigquery.googleapis.com/bigquery/v2/projects/{{ project-id }}/queries? \
         # prettyPrint=false:Could not serialize access to table {{ project-id }}:{{ table }} due to concurrent update
         def decorator(func):
@@ -100,17 +100,21 @@ class BigQueryClient(Connection):
                         return func(self, *args, **kwargs)
                     except BadRequest as error:
                         if (count < max_retries) and ("concurrent update" in str(error)):
-                            time.sleep(delay)
+                            if random_delay is not None:
+                                import random
+                                time.sleep(random.uniform(*random_delay))
+                            else:
+                                time.sleep(delay)
                             continue
                         raise error
             return wrapper
         return decorator
 
-    @retry_on_concurrent_update(max_retries=5, delay=1)
+    @retry_on_concurrent_update(max_retries=5, random_delay=(1,3))
     def execute(self, query: str, **kwargs) -> QueryJob:
         return self.conn.query(query, **kwargs)
 
-    @retry_on_concurrent_update(max_retries=5, delay=1)
+    @retry_on_concurrent_update(max_retries=5, random_delay=(1,3))
     def execute_job(self, query: str, **kwargs) -> RowIterator:
         return self.conn.query_and_wait(query, **kwargs)
 
@@ -295,21 +299,23 @@ class BigQueryClient(Connection):
             not_matched: Clause | Columns | Literal[":insert_all:",":do_nothing:"] = ":insert_all:",
             where_clause: Clause | None = None,
         ) -> LoadJob:
-        where = [f"T.{where_clause}"] if where_clause else list()
+        """When using where_clause, reference target table columns with \"T.\" and source table columns with \"S.\""""
+        where = [where_clause] if where_clause else list()
         on = " AND ".join([f"T.{col} = S.{col}" for col in ([on] if isinstance(on, str) else on)]+where)
         query = f"MERGE INTO `{self.project_id}.{target_table}` AS T USING `{self.project_id}.{source_table}` AS S ON {on}"
-        query = concat_sql(query, self._merge_update(matched, on), self._merge_insert(not_matched, target_table))
+        query = concat_sql(query, self._merge_update(matched, target_table, on), self._merge_insert(not_matched, target_table))
         return self.execute_job(query)
 
     def _merge_update(
             self,
             matched: Clause | dict[str,Literal["replace","ignore","greatest","least","source_first","target_first"]] | Literal[":replace_all:",":do_nothing:"] = ":replace_all:",
+            target_table: str = str(),
             on: str | Sequence[str] = list(),
         ) -> str:
         prefix = "WHEN MATCHED THEN UPDATE SET "
         if matched == ":replace_all:":
             on = [on] if isinstance(on, str) else on
-            return self._merge_update({col: "replace" for col in self.get_columns() if col not in on})
+            return self._merge_update({col: "replace" for col in self.get_columns(target_table) if col not in on})
         elif matched == ":do_nothing:":
             return None
         elif isinstance(matched, dict):
@@ -359,6 +365,7 @@ class BigQueryClient(Connection):
             table_lock_wait_timeout: float | int | None = 60.,
             drop_stage_after_merge: bool = True,
         ) -> LoadJob:
+        """When using where_clause, reference target table columns with \"T.\" and source table columns with \"S.\""""
         try:
             self._wait_until_table_not_found(stage_table, table_lock_wait_interval, table_lock_wait_timeout)
             self.load_table_from_file(source_file, stage_table, source_format, schema, write, if_not_found)
@@ -501,9 +508,11 @@ class BigQueryClient(Connection):
             if_staging_table_exists: Literal["errors","ignore","replace"] = "replace",
             drop_stage_after_merge: bool = True,
         ) -> bool:
+        """When using where_clause, reference target table columns with \"T.\" and source table columns with \"S.\""""
+        import re
         if not connection.table_exists(source_table):
             return True
-        elif not self.table_has_rows(target_table, where_clause):
+        elif not self.table_has_rows(target_table, (re.sub(r"(^|[^A-Za-z0-9_])(T|S)\.", r"\1", where_clause) if where_clause else None)):
             return self.load_table_from_duckdb(connection, source_table, target_table, dict(), schema, "append", if_not_found, progress)
 
         try:
