@@ -8,6 +8,8 @@ if TYPE_CHECKING:
 
 def safe_float(object_: Any, default: float | None = None) -> float:
     try:
+        if isinstance(object_, str) and (',' in object_):
+            object_ = object_.replace(',', '')
         return float(object_)
     except:
         return default
@@ -15,6 +17,8 @@ def safe_float(object_: Any, default: float | None = None) -> float:
 
 def safe_int(object_: Any, default: int | None = None) -> int:
     try:
+        if isinstance(object_, str) and (',' in object_):
+            object_ = object_.replace(',', '')
         return int(float(object_))
     except:
         return default
